@@ -17,8 +17,6 @@ from __future__ import print_function
 
 from Bio._py3k import range
 
-import math
-
 
 def create(instances, alphabet=None):
     instances = Instances(instances, alphabet)
@@ -303,7 +301,10 @@ class Motif(object):
             self._background = dict.fromkeys(self.alphabet.letters, 1.0)
         else:
             if sorted(self.alphabet.letters) != ["A", "C", "G", "T"]:
-                raise Exception("Setting the background to a single value only works for DNA motifs (in which case the value is interpreted as the GC content")
+                # TODO - Should this be a ValueError?
+                raise Exception("Setting the background to a single value only "
+                                "works for DNA motifs (in which case the value "
+                                "is interpreted as the GC content")
             self._background['A'] = (1.0 - value) / 2.0
             self._background['C'] = value / 2.0
             self._background['G'] = value / 2.0
@@ -505,7 +506,6 @@ class Motif(object):
          - jaspar : JASPAR multiple Position Frequency Matrix
          - transfac : TRANSFAC like files
         """
-
         if format in ('pfm', 'jaspar'):
             from Bio.motifs import jaspar
             motifs = [self]
@@ -526,7 +526,6 @@ def write(motifs, format):
      - jaspar : JASPAR multiple PFM format
      - transfac : TRANSFAC like files
     """
-
     format = format.lower()
     if format in ("pfm", "jaspar"):
         from Bio.motifs import jaspar
